]> sigrok.org Git - libsigrokdecode.git/blobdiff - util.c
Use g_try_malloc/g_free/g_strdup consistently.
[libsigrokdecode.git] / util.c
diff --git a/util.c b/util.c
index 5f186398a7697141c1d7acee44f34f019acddd96..cd77fc10481836aa3c9057e0d06a3360cecd9135 100644 (file)
--- a/util.c
+++ b/util.c
@@ -23,7 +23,7 @@
 #include "config.h"
 
 /**
- * Get the value of a python object's attribute, returned as a newly
+ * Get the value of a Python object's attribute, returned as a newly
  * allocated char *.
  *
  * @param py_obj The object to probe.
@@ -63,7 +63,7 @@ SRD_PRIV int py_attr_as_str(PyObject *py_obj, const char *attr, char **outstr)
 }
 
 /**
- * Get the value of a python dictionary item, returned as a newly
+ * Get the value of a Python dictionary item, returned as a newly
  * allocated char *.
  *
  * @param py_obj The dictionary to probe.
@@ -102,7 +102,7 @@ SRD_PRIV int py_dictitem_as_str(PyObject *py_obj, const char *key,
 }
 
 /**
- * Get the value of a python unicode string object, returned as a newly
+ * Get the value of a Python unicode string object, returned as a newly
  * allocated char *.
  *
  * @param py_str The unicode string object.
@@ -138,7 +138,7 @@ SRD_PRIV int py_str_as_str(PyObject *py_str, char **outstr)
        }
 
        if (!(*outstr = g_strdup(str))) {
-               srd_dbg("outstr malloc failed");
+               srd_dbg("Failed to g_malloc() outstr.");
                ret = SRD_ERR_MALLOC;
                goto err_out;
        }
@@ -155,14 +155,14 @@ err_out:
 }
 
 /**
- * Convert a python list of unicode strings to a NULL-terminated UTF8-encoded
- * char * array. The caller must free each string when finished.
+ * Convert a Python list of unicode strings to a NULL-terminated UTF8-encoded
+ * char * array. The caller must g_free() each string when finished.
  *
  * @param py_strlist The list object.
  * @param outstr ptr to char ** storage to be filled in.
  *
  * @return SRD_OK upon success, a (negative) error code otherwise.
*         The 'outstr' argument points to a malloc()ed char ** upon success.
  */
 SRD_PRIV int py_strlist_to_char(PyObject *py_strlist, char ***outstr)
 {
@@ -171,8 +171,10 @@ SRD_PRIV int py_strlist_to_char(PyObject *py_strlist, char ***outstr)
        char **out, *str;
 
        list_len = PyList_Size(py_strlist);
-       if (!(out = g_try_malloc(sizeof(char *) * (list_len + 1))))
+       if (!(out = g_try_malloc(sizeof(char *) * (list_len + 1)))) {
+               srd_err("Failed to g_malloc() 'out'.");
                return SRD_ERR_MALLOC;
+       }
        for (i = 0; i < list_len; i++) {
                if (!(py_str = PyUnicode_AsEncodedString(
                    PyList_GetItem(py_strlist, i), "utf-8", NULL)))
@@ -155,14 +155,14 @@ err_out:
  *
  * @return SRD_OK upon success, a (negative) error code otherwise.
- *         The 'outstr' argument points to a malloc()ed char ** upon success.
+ *         The 'outstr' argument points to a g_malloc()ed char** upon success.
  */
 SRD_PRIV int py_strlist_to_char(PyObject *py_strlist, char ***outstr)